/*
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/*
 * Author: Joshua Vasquez
 * Date last revised: June 23, 2012
 *
 * Mindstorms PS3 control Processing Sketch:
 *
 *  This sketch does the following four things:
 * 1. Create a serial port between the two xbee modules.
       (Connects PC to Arduino)
 * 2. Create a PS3 controller interface to read stick values.
       (Connects PS3 to PC)
 * 3. Polls the latest PS3 stick data and packs it into a
 *    custom 3-byte data packet to pass to the Arduino.
 * 4. Sends data packet at regular intervals.
 */

// NOTE: THIS PROGRAM DOES NOT WORK WITH A WACOM TABLET CONNECTED


// Import functions from three libraries:
import procontroll.*;
import java.io.*;
import processing.serial.*;



// Create instances of specific hardware components:
ControllIO controll;
ControllDevice device;

ControllStick stick1;
ControllStick stick2;

// Create a serial port instance:
Serial port;

// Global (eek!) variables:
byte y_left;
byte y_right;

char PacketStart = '~';  // to signifiy the start of a data packet

void setup()
{
  size(100,100);
  
  // Open a serial port with device 0 at the defined speed:
  port = new Serial(this, Serial.list()[0], 9600); 
  
  // Instantiate input/output capabilities:
  controll = ControllIO.getInstance(this);
  
  // lock onto the PS3 Controller:
  device = controll.getDevice("PLAYSTATION(R)3 Controller");
  
  // Recover the name of the controller from the printDevice() command
  //device.printSticks();

  // Assing variable names to both PS3 sticks: 
  stick1 = device.getStick("y x");
  stick2 = device.getStick("rz z");
  
  // These settings indicate how much you must tilt the stick before it registers
  stick1.setTolerance(0.10f); 
  stick2.setTolerance(0.10f);

 // Drawing settings:
  fill(0);
  rectMode(CENTER);
}


//The main loop:
void draw()
{
  
  background(255);
  
  // Grab both stick y-values, ...which are mapped to getX()  (?)
  y_left = (byte) map(stick1.getX(), 1, -1, -100, 100) ;
  y_right = (byte) map(stick2.getX(), 1, -1, -100, 100) ;

/*  // for debugging:
  print(y_left);
   print("  ");
  println(y_right);
*/
  
  // Send over the serial data:
  port.write( PacketStart );  //  
  port.write(y_left);
  port.write(y_right);

  // Draw two representative circles:
  ellipse( (width/2 - 10),
        (-(y_left/5) + height/2),
        10,
        10);
        
  ellipse( (width/2 + 10),
        (-(y_right/5) + height/2),
        10,
        10);
}
